﻿using Syncfusion.JavaScript.Web;
using Syncfusion.XlsIO;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Web.UserControls;

namespace Web
{
    public partial class _Default : Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!String.IsNullOrEmpty(ddlTeam.Value))
                CreateReports();
        }

        private List<Report> LoadData(int team)
        {
            List<Report> lstReports = new List<Report>();

            lstReports.Add(new Report(1, "Altas", 10, 5, 75));
            lstReports.Add(new Report(1, "Bajas", 20, 55, 20));
            lstReports.Add(new Report(2, "Altas", 30, 50, 35));
            lstReports.Add(new Report(2, "Bajas", 40, 70, 75));
            lstReports.Add(new Report(3, "Altas", 50, 65, 55));
            lstReports.Add(new Report(3, "Bajas", 60, 95, 45));
            lstReports.Add(new Report(4, "Altas", 70, 55, 35));
            lstReports.Add(new Report(4, "Bajas", 80, 15, 25));

            return lstReports.Where(x => x.IdTeam == team).ToList<Report>();
        }


        protected void btnGenerarInforme_Click(object Sender, Syncfusion.JavaScript.Web.ButtonEventArgs e)
        {
            CreateReports();
        }

        private void CreateReports()
        {
            IEnumerable<int> teams = null;

                
            if (String.IsNullOrEmpty(ddlTeam.Value))
                {
                    ModelState.AddModelError("", "Debe seleccionar almenos algún Team para generar el informe");
                    return;
                }

            teams = ddlTeam.Value.Split(',').Where((valor) => Int32.Parse(valor) > 0).Select(Int32.Parse).ToArray<int>();

            panelReports.Controls.Clear();

            foreach (int team in teams)
            {
                var data = LoadData(team);
                DatosInformeGasTeam diTeam = (DatosInformeGasTeam)LoadControl("~/UserControls/DatosInformeGasTeam.ascx");
                diTeam.ID = team.ToString();
                diTeam.GenerarInformes(data);
                panelReports.Controls.Add(diTeam);
            }
        }

        protected void btnExportAll_Click(object Sender, Syncfusion.JavaScript.Web.ButtonEventArgs e)
        {
            ExcelEngine excelEngine = new ExcelEngine();
            excelEngine.ThrowNotSavedOnDestroy = false;
            IApplication application = excelEngine.Excel;
            IWorkbook workbook = application.Workbooks.Create(1);
            workbook.ThrowOnUnknownNames = false;
            workbook.Version = ExcelVersion.Excel2013;

            foreach (DatosInformeGasTeam di in panelReports.Controls)
            {
                IWorkbook excel = di.ExportarExcel();
                IWorksheet worksheet;
                worksheet = excel.Worksheets[0];
                workbook.Worksheets.AddCopy(worksheet);
            }

            workbook.Worksheets.Remove(0);
            workbook.SaveAs("Informes.xlsx", ExcelSaveType.SaveAsXLS, Response, ExcelDownloadType.PromptDialog, ExcelHttpContentType.Excel2013);

        }



    }
}